@@ -1,12 +1,12 @@
-;;; edit-server.el --- server that responds to edit requests from Chrome
+;;; edit-server.el --- server that responds to edit requests from Chrome  -*- lexical-binding: t -*-
 
 ;; Copyright (C) 2009-2013  Alex Bennée
 ;; Copyright (C) 2010-2011  Riccardo Murri
 
 ;; Author: Alex Bennée <alex@bennee.com>
 ;; Maintainer: Alex Bennée <alex@bennee.com>
-;; Package-Version: 1.16
-;; Package-Revision: 1632acab5624
+;; Package-Version: 20260104.1224
+;; Package-Revision: c7cb4cb0043e
 ;; Homepage: https://github.com/stsquad/emacs_chrome
 
 ;; This file is not part of GNU Emacs.
@@ -129,8 +129,8 @@ edit-server-start-hook instead."
     (minibuffer . t)
     (menu-bar-lines . t))
   "Frame parameters for new frames.  See `make-frame' for examples.
-You will want to look at the VALUE of 'window-system', 'display' and
-'terminal' if you want to force any particular display type and
+You will want to look at the VALUE of `window-system', `display' and
+`terminal' if you want to force any particular display type and
 not default to whatever is currently open. If nil, the new
 frame will use the existing `default-frame-alist' values."
   :group 'edit-server
@@ -277,7 +277,8 @@ send a response back to the client."
     (edit-server-edit-mode t)))
 
 (define-globalized-minor-mode global-edit-server-edit-mode
-  edit-server-edit-mode turn-on-edit-server-edit-mode-if-server)
+  edit-server-edit-mode turn-on-edit-server-edit-mode-if-server
+  :group 'edit-server)
 (global-edit-server-edit-mode t)
 
 
@@ -295,11 +296,12 @@ send a response back to the client."
 ;; to avoid when edit-server has no active clients.  So it seems that
 ;; advice is the only solution until save-buffers-kill-emacs offers an
 ;; earlier hook.
-(defadvice save-buffers-kill-emacs
-      (before edit-server-stop-before-kill-emacs)
-      "Call `edit-server-stop' if there are no active clients, to
+(defun edit-server-stop-before-kill-emacs (&rest _)
+  "Call `edit-server-stop' if there are no active clients, to
 avoid the user being prompted to kill the edit-server process."
-      (or edit-server-clients (edit-server-stop)))
+  (or edit-server-clients (edit-server-stop)))
+
+(advice-add 'save-buffers-kill-emacs :before #'edit-server-stop-before-kill-emacs)
 
 ;;;###autoload
 (defun edit-server-start (&optional verbose)
@@ -311,7 +313,7 @@ will cause it to be verbose."
   (interactive "P")
   (if (process-status "edit-server")
       (message "An edit-server process is already running")
-    (if (null (condition-case err
+    (unless (null (condition-case err
                   (let ((proc (make-network-process
                                :name "edit-server"
                                :buffer edit-server-process-buffer-name
@@ -323,9 +325,10 @@ will cause it to be verbose."
                                :noquery t)))
                     (set-process-coding-system proc 'utf-8 'utf-8)
                     proc)
-                (file-error nil)))
-        (message "Failed to start an edit-server")
-      (ad-activate 'save-buffers-kill-emacs)
+                  (file-error
+                   (message "Failed to start an edit-server:%s" err)
+                   nil)))
+      (advice-add 'save-buffers-kill-emacs :before #'edit-server-stop-before-kill-emacs)
       (setq edit-server-clients '())
       (when verbose (get-buffer-create edit-server-log-buffer-name))
       (edit-server-log nil "Created a new edit-server process"))))
@@ -341,11 +344,7 @@ will cause it to be verbose."
     (message "No edit server running"))
   (when (get-buffer edit-server-process-buffer-name)
     (kill-buffer edit-server-process-buffer-name))
-  (ad-disable-advice 'save-buffers-kill-emacs
-                     'before 'edit-server-stop-before-kill-emacs)
-  ;; Disabling advice doesn't take effect until you (re-)activate
-  ;; all advice for the function.
-  (ad-activate 'save-buffers-kill-emacs))
+  (advice-remove 'save-buffers-kill-emacs #'edit-server-stop-before-kill-emacs))
 
 (defun edit-server-log (proc fmt &rest args)
   "If a `*edit-server-log*' buffer exists, write STRING to it.
@@ -353,7 +352,7 @@ This is done for logging purposes.  If `edit-server-verbose' is
 non-nil, then STRING is also echoed to the message line."
   (let ((string (apply 'format fmt args)))
     (when edit-server-verbose
-      (message string))
+      (message "%s" string))
     (when (get-buffer edit-server-log-buffer-name)
       (with-current-buffer edit-server-log-buffer-name
 	(goto-char (point-max))
@@ -367,7 +366,7 @@ non-nil, then STRING is also echoed to the message line."
 		string)
 	(or (bolp) (newline))))))
 
-(defun edit-server-accept (server client msg)
+(defun edit-server-accept (_server client msg)
   "Accept a new client connection."
   (let ((buffer (generate-new-buffer edit-server-process-buffer-name)))
     (buffer-disable-undo buffer)
@@ -478,14 +477,14 @@ non-nil, then STRING is also echoed to the message line."
 to be passed into the kill ring.
 
 The new frame will have a specific frame parameter of
-  `edit-server-forground-frame' set to 't"
+  `edit-server-foreground-frame' set to `t'."
   (when (bufferp buffer)
     (with-current-buffer buffer
       (kill-ring-save (point-min) (point-max))))
 
   (when edit-server-new-frame
     (set-frame-parameter
-     (edit-server-make-frame) 'edit-server-forground-frame 't)))
+     (edit-server-make-frame) 'edit-server-foreground-frame 't)))
 
 (defun edit-server-show-edit-buffer (buffer)
   "Show edit `BUFFER' by creating a frame or raising the selected
